Module prelude

Module prelude 

Re-exports

pub use crate::cf::Cf;
pub use crate::context::Context;
pub use crate::durable_object;
pub use crate::file::File;
pub use crate::formdata::FormData;
pub use crate::global::set_timeout;
pub use crate::global::WorkerGlobalScope;
pub use crate::headers::Headers;
pub use crate::request::Request;
pub use crate::response::Response;
pub use crate::queue::*;
pub use crate::request_init::*;
pub use crate::schedule::*;

Macros

console_debug
When debugging your Worker via wrangler dev, wrangler tail, or from the Workers Dashboard, anything passed to this macro will be printed to the terminal or written to the console.
console_error
When debugging your Worker via wrangler dev, wrangler tail, or from the Workers Dashboard, anything passed to this macro will be printed to the terminal or written to the console.
console_log
When debugging your Worker via wrangler dev, wrangler tail, or from the Workers Dashboard, anything passed to this macro will be printed to the terminal or written to the console.
console_warn
When debugging your Worker via wrangler dev, wrangler tail, or from the Workers Dashboard, anything passed to this macro will be printed to the terminal or written to the console.